Index: trunk/psLib/src/math/psSpline.h
===================================================================
--- trunk/psLib/src/math/psSpline.h	(revision 4315)
+++ trunk/psLib/src/math/psSpline.h	(revision 4330)
@@ -12,6 +12,6 @@
  *  @author GLG, MHPCC
  *
- *  @version $Revision: 1.47 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-18 02:30:49 $
+ *  @version $Revision: 1.48 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-21 03:01:37 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -39,5 +39,5 @@
  *        \f[ exp(-\frac{(x-mean)^2}{2\sigma^2}) \f]
  *
  *  @return psF32      value on the gaussian curve given the input parameters
  */
 float psGaussian(
@@ -218,5 +218,5 @@
  */
 psVector *psPolynomial2DEvalVector(
-    const psPolynomial2D *myPoly,      ///< Coefficients for the polynomial
+    const psPolynomial2D *poly,         ///< Coefficients for the polynomial
     const psVector *x,                  ///< x locations at which to evaluate
     const psVector *y                   ///< y locations at which to evaluate
@@ -444,8 +444,8 @@
  *  @return psSpline1D*    new 1-D spline struct
  */
-psSpline1D *psSpline1DAlloc(psS32 n,             ///< Number of spline polynomials
-                            psS32 order,         ///< Order of spline polynomials
-                            psF32 min,           ///< Lower boundary value of spline polynomials
-                            psF32 max);          ///< Upper boundary value of spline polynomials
+psSpline1D *psSpline1DAlloc(int n,               ///< Number of spline polynomials
+                            int order,           ///< Order of spline polynomials
+                            float min,           ///< Lower boundary value of spline polynomials
+                            float max);          ///< Upper boundary value of spline polynomials
 
 /** Allocates a psSpline1D structure
@@ -456,13 +456,13 @@
  */
 psSpline1D *psSpline1DAllocGeneric(const psVector *bounds,   ///< Bounds for spline polynomials
-                                   psS32 order);             ///< Order of spline polynomials
+                                   int order);               ///< Order of spline polynomials
 
 /** Evaluates 1-D spline polynomials at a specific coordinate.
  *  
- *  @return psF32    result of spline polynomials evaluated at given location
- */
-psF32 psSpline1DEval(
+ *  @return float    result of spline polynomials evaluated at given location
+ */
+float psSpline1DEval(
     const psSpline1D *spline,          ///< Coefficients for spline polynomials
-    psF32 x                            ///< location at which to evaluate
+    float x                            ///< location at which to evaluate
 );
 
@@ -39,5 +39,5 @@
  *        \f[ exp(-\frac{(x-mean)^2}{2\sigma^2}) \f]
  *
- *  @return psF32      value on the gaussian curve given the input parameters
+ *  @return float      value on the gaussian curve given the input parameters
  */
 float psGaussian(
